@@ -31,7 +31,7 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL license and that you accept its terms.
 # -----------------------------------------------------------------------------
-'''
+"""
 Equation class.
 
 The Equation class allows to manipulate equations of the type:
@@ -48,17 +48,18 @@ case, an `EquationError` is raised.
 >>> eq = Equation('y = a+b*x')
 >>> y = eq.evaluate(1,2,3)             # a=1, b=2, x=3
 >>> y = eq.evaluate(x=1, b=2, a=3)     # a=3, b=2, x=1
-'''
+"""
 import re
-import numpy as np
 import inspect
-from definition import Definition
+import compiler
+from definition import Definition, Visitor
+
 
 class EquationError(Exception):
     pass
 
 class Equation(Definition):
-    ''' Equation of type: 'y = expr : dtype'
+    """ Equation of type: 'y = expr : dtype'
 
     The Equation class allows to manipulate equations of the type:
 
@@ -74,25 +75,27 @@ class Equation(Definition):
     >>> eq = Equation('y = a+b*x')
     >>> y = eq.evaluate(1,2,3)             # a=1, b=2, x=3
     >>> y = eq.evaluate(x=1, b=2, a=3)     # a=3, b=2, x=1
-    ''' 
+    """
 
-    def __init__(self, definition, known_variables=None):
-        '''
-        Creates equation if `definition` is of the right form.
+    def __init__(self, definition, constants=None, variables=None):
+        """
+        Creates equation.
 
-        **Parameters**
-
-        definition : str
-            Equation definition of the form 'y = expr : dtype'
-            expr must be a valid python expression.
-
-        '''
+        :param string definition:
+            Equation definition of the form:
+        :param list constants:
+            Name of variables that must be considered constant
+        """
+        if not variables: variables = []
+        if not constants: constants = {}
         Definition.__init__(self,definition)
-        self.parse()
+        self._in_out = None
+        self._out = None
+        self.setup()
 
 
-    def parse(self, definition = None, known_variables = []):
-        '''
+    def setup(self, constants=None):
+        """
         Parse definition and check it is an equation.
 
         **Parameters**
@@ -100,97 +103,94 @@ class Equation(Definition):
         definition : str
             Equation definition of the form 'y = expr : dtype'
             expr must be a valid python expression.
-        '''
-        if definition is not None:
-            self._definition = definition
-        definition = str(self._definition.replace(' ',''))
+        """
+        if not constants: constants = {}
 
         # Check if equation is of the form: y = f(...) : dtype
         p = re.compile(
             r'''(?P<y>\w+) = (?P<f>[^:]+) (:(?P<dtype>\w+))?''', re.VERBOSE)
-        result = p.match(definition)
+        result = p.match(self._definition)
         if result:
             y = result.group('y').strip()
             f = result.group('f').strip()
             dtype = (result.group('dtype') or 'float').strip()
-            self._varname = y
             self._lhs = y
+            self._varname = y
             self._rhs = f
-            self.__f__ = eval('lambda: %s' % f)
+            self._dtype = dtype
+            visitor = Visitor()
+            compiler.walk(compiler.parse(f), visitor)
+            variables = visitor._vars
 
-            # This line get all strings from function code definition...
-            self._variables = list(self.__f__.func_code.co_names)
-            #  ... and we need to sort out actual variables from function names
-            namespace = {}
-            numpy_ns = {}
-            for key in dir(np):
-                numpy_ns[key] = getattr(np,key)
-            for i in range(0,len(inspect.stack())):
-                frame = inspect.stack()[i][0]
-                for name in self.__f__.func_code.co_names:
-                    if ((name in self._variables) and (name != self._varname)
-                        and (name not in known_variables)):
-                        if name in numpy_ns.keys() and callable(eval(name, numpy_ns)):
-                            namespace[name] = numpy_ns[name]
-                            self._variables.remove(name)
-                        if name in frame.f_locals.keys() and callable(eval(name, frame.f_locals)):
-                            namespace[name] = frame.f_locals[name]
-                            self._variables.remove(name)
-            args = self.__f__.func_code.co_names
-            if len(args):
-                args = ' = 0, '.join(self._variables)+ ' = 0'
+            # Make sure to get function form highest stack frame
+            # since the function name can be also defined locally
+            ns = {}
+            for name in visitor._funcs:
+                for i in range(1,len(inspect.stack())):
+                    frame = inspect.stack()[i][0]
+                    name = name.split('.')[0]
+                    if name in frame.f_locals.keys() and name not in ns.keys():
+                        ns[name] = frame.f_locals[name]
+                        break
+            ns.update(constants)
+
+            variables = list(set(variables) - set(constants.keys()))
+            self._variables = variables
+
+            if len(variables):
+                args = ' = 0, '.join(variables)+ ' = 0'
             else:
                 args = ''
-            self.__f__ = eval('lambda %s: %s' % (args,f), namespace)
-            self._dtype = dtype
+            self.__f__ = eval('lambda %s: %s' % (args,f),ns)
         else:
             raise EquationError, 'Definition is not an equation'
 
 
     def __call__(self, *args, **kwargs):
-        '''
+        """
         Evaluate equation
-        
+
         **Parameters**
 
         args : list
             Equation constants (respecting definition order)
         kwargs : dict
             Equation constants
-            
+
         **Examples**
 
         >>> eq = Equation('y = a+b*x')
         >>> y = eq.evaluate(1,2,3)             # a=1, b=2, x=3
         >>> y = eq.evaluate(x=1, b=2, a=3)     # a=3, b=2, x=1
-        '''
-
+        """
+        
         return self.__f__(*args, **kwargs)
 
 
     def evaluate(self, *args, **kwargs):
-        '''
+        """
         Evaluate equation
-        
+
         **Parameters**
 
         args : list
             Equation constants (respecting definition order)
         kwargs : dict
             Equation constants
-            
+
         **Examples**
 
         >>> eq = Equation('y = a+b*x')
         >>> y = eq.evaluate(1,2,3)             # a=1, b=2, x=3
         >>> y = eq.evaluate(x=1, b=2, a=3)     # a=3, b=2, x=1
-        '''
+        """
+
         return self.__f__(*args, **kwargs)
 
 
 
     def _get_variables(self):
-        '''Get equation variables'''
+        """Get equation variables"""
         return self._variables
     variables = property(_get_variables,
                          doc='''Equation variable names''')
