@@ -31,13 +31,50 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL license and that you accept its terms.
 # -----------------------------------------------------------------------------
-''' Some useful functions '''
+""" Some useful functions """
 import numpy as np
 import scipy.linalg
 import scipy.sparse as sp
 from scipy.ndimage.filters import convolve
 from group import Group
 
+def best_fft_shape(shape):
+    """
+    From fftw.org:
+        FFTW is best at handling sizes of the form 2^a*3^b*5^c*7^d*11^e*13^f,
+         where e+f is either 0 or 1,
+
+    This function finds the best shape for computing fftw
+    """
+
+    base = [13,11,7,5,3,2]
+
+    def factorize(n):
+        if not n:
+            raise(RuntimeError, "Length n must be positive integer")
+        elif n == 1:
+            return [1,]
+        factors = []
+        for b in base:
+            while n % b == 0:
+                n /= b
+                factors.append(b)
+        if n == 1:
+            return factors
+        return []
+
+    def is_optimal(n):
+        factors = factorize(n)
+        return len(factors) > 0 \
+            and factors[:2] not in [[13,13],[13,11],[11,11]]
+
+    shape = np.atleast_1d(np.array(shape))
+    for i in range(shape.size):
+        while not is_optimal(shape[i]):
+            shape[i] += 1
+    return shape.astype(int)
+
+
 
 def convolve1d(Z, K, toric=False):
     """ Discrete, clamped, linear convolution of two one-dimensional sequences.
@@ -48,17 +85,14 @@ def convolve1d(Z, K, toric=False):
         distributed according to the convolution of their individual
         distributions.
     
-        **Parameters**
-
-            Z : (N,) array_like
-                First one-dimensional input array (input).
-            K : (M,) array_like
-                Second one-dimensional input array (kernel).
-
-        **Returns**
-
-            out : array
-                Discrete, clamped, linear convolution of `Z` and `K`.
+        :param array Z:
+            One-dimensional array.
+        :param array K:
+            One-dimensional array.
+        :param bool toric:
+            Indicate whether convolution should be considered toric
+        :return: 
+            Discrete, clamped, linear convolution of `Z` and `K`.
 
         **Note**
 
@@ -98,17 +132,17 @@ def convolve2d(Z, K, USV = None, toric=False):
         singular value decomposition [2]_ and the computing is optimized
         accordingly (when rank n is inferior to S.size/2)
     
-        **Parameters**
 
-            Z : (N1,N2) array_like
-                First two-dimensional input array (input).
-            K : (M1,M2) array_like
-                Second two-dimensional input array (kernel).
-
-        **Returns**
-
-            out : ndarray
-                Discrete, clamped, linear convolution of `Z` and `K`.
+        :param array Z:
+            Two-dimensional array.
+        :param array K:
+            Two-dimensional array.
+        :param tuple USV
+            (U,S,V) as a result of scipy.linalg.svd(K).
+        :param bool toric:
+            Indicate whether convolution should be considered toric
+        :return: 
+            Discrete, clamped, linear convolution of `Z` and `K`.
 
         **Note**
 
@@ -237,7 +271,7 @@ def extract(Z, shape, position, fill=0):
 
 
 def convolution_matrix(src, dst, kernel, toric=False):
-    '''
+    """
     Build a sparse convolution matrix M such that:
 
     (M*src.ravel()).reshape(src.shape) = convolve2d(src,kernel)
@@ -281,7 +315,7 @@ def convolution_matrix(src, dst, kernel, toric=False):
     [[ 4.  6.  4.]
      [ 6.  9.  6.]
      [ 4.  6.  4.]]
-    '''
+    """
  
     # For a toric connection, it is wrong to have a kernel larger
     # than the source
@@ -316,7 +350,7 @@ def convolution_matrix(src, dst, kernel, toric=False):
     for index in np.ndindex(dst.shape):
         dims = []
         # Are we starting a new dimension ?
-        if index[-1] == 0:
+        if not index[-1]:
             for i in range(len(index)-1,0,-1):
                 if index[i]: break
                 dims.insert(0,i-1)
@@ -335,7 +369,7 @@ def convolution_matrix(src, dst, kernel, toric=False):
             #     z = (indices[dim][dim] - src.shape[dim]/2.0 -(kernel.shape[dim]+1)%2+ src_indices[dim][i])
 
             n = np.where((z >= 0)*(z < src.shape[dim]))[0]
-            if dim == 0:
+            if not dim:
                 nd[dim] = n.copy()
             else:
                 nd[dim] = nd[dim-1][n]
@@ -395,7 +429,7 @@ def convolution_matrix(src, dst, kernel, toric=False):
 
 
 def gaussian(shape=(25,25), width=0.5, center=0.0):
-    ''' Generate a gaussian of the form g(x) = height*exp(-(x-center)**2/width**2).
+    """ Generate a gaussian of the form g(x) = height*exp(-(x-center)**2/width**2).
 
     **Parameters**
 
@@ -411,7 +445,7 @@ def gaussian(shape=(25,25), width=0.5, center=0.0):
     **Returns**
 
        a numpy array of specified shape containing a gaussian
-    '''
+    """
     if type(shape) in [float,int]:
         shape = (shape,)
     if type(width) in [float,int]:
@@ -429,21 +463,17 @@ def gaussian(shape=(25,25), width=0.5, center=0.0):
     return np.exp(-R/2)
 
 def empty(shape, dtype=float):
-    '''
+    """
     Return a new group of given shape and type, without initialising entries.
 
-    **Parameters**
 
-    shape : {tuple of ints, int}
+    :param tuple shape:
         Shape of the new group, e.g., ``(2, 3)`` or ``2``.
-    dtype : data-type, optional
+    :param dtype:
         The desired data-type for the group, e.g., `np.int8`.  Default is
         `np.float64`.
-    
-    **Returns**
-
-    out : group
-        Group with the given shape and dtype.
+    :return:
+        Group with the given shape and dtype filled with zeros.
 
     **Notes**
 
@@ -456,7 +486,7 @@ def empty(shape, dtype=float):
 
     >>> Group.empty((2,2))
     Group([[6.94248367807e-310, 1.34841898023e-316],
-           [1.34841977073e-316, 0.0]], 
+           [1.34841977073e-316, 0.0]],
           dtype=[('f0', '<f8')])
 
     **See also**
@@ -466,35 +496,30 @@ def empty(shape, dtype=float):
     * :meth:`dana.zeros_like` : Return a group of zeros with shape and type of input.
     * :meth:`dana.ones_like` : Return a group of ones with shape and type of input.
     * :meth:`dana.empty_like` : Return a empty group with shape and type of input.
-    '''
+    """
     return Group(shape=shape, dtype=dtype, fill=None)
 
 def zeros(shape, dtype=float):
-    '''
+    """
     Return a new group of given shape and type, filled with zeros.
 
-    **Parameters**
-
-    shape : {tuple of ints, int}
+    :param tuple shape:
         Shape of the new group, e.g., ``(2, 3)`` or ``2``.
-    dtype : data-type, optional
+    :param dtype:
         The desired data-type for the group, e.g., `np.int8`.  Default is
         `np.float64`.
-    
-    **Returns**
-
-    out : group
+    :return:
         Group with the given shape and dtype filled with zeros.
 
     **Examples**
 
     >>> dana.zeros((2,2))
     Group([[0.0, 0.0],
-           [0.0, 0.0]], 
+           [0.0, 0.0]],
           dtype=[('f0', '<f8')])
     >>> dana.zeros((2,2), dtype=int)
     Group([[0, 0],
-           [0, 0]], 
+           [0, 0]],
           dtype=[('f0', '<f8')])
 
     **See also**
@@ -504,35 +529,30 @@ def zeros(shape, dtype=float):
     * :meth:`dana.zeros_like` : Return an group of zeros with shape and type of input.
     * :meth:`dana.ones_like` : Return an group of ones with shape and type of input.
     * :meth:`dana.empty_like` : Return an empty group with shape and type of input.
-    '''
+    """
     return Group(shape=shape, dtype=dtype, fill=0)
 
 def ones(shape, dtype=float):
-    '''
+    """
     Return a new group of given shape and type, filled with ones.
 
-    **Parameters**
-
-    shape : {tuple of ints, int}
+    :param tuple shape:
         Shape of the new group, e.g., ``(2, 3)`` or ``2``.
-    dtype : data-type, optional
+    :param dtype:
         The desired data-type for the group, e.g., `np.int8`.  Default is
         `np.float64`.
-    
-    **Returns**
-
-    out : group
-        Group with the given shape and dtype filled with ones.
+    :return:
+        Group with the given shape and dtype filled with zeros.
 
     **Examples**
 
     >>> dana.ones((2,2))
     Group([[1.0, 1.0],
-           [1.0, 1.0]], 
+           [1.0, 1.0]],
           dtype=[('f0', '<f8')])
     >>> dana.ones((2,2), dtype=int)
     Group([[1, 1],
-           [1, 1]], 
+           [1, 1]],
           dtype=[('f0', '<f8')])
 
     **See also**
@@ -542,23 +562,18 @@ def ones(shape, dtype=float):
     * :meth:`dana.zeros_like` : Return an group of zeros with shape and type of input.
     * :meth:`dana.ones_like` : Return an group of ones with shape and type of input.
     * :meth:`dana.empty_like` : Return an empty group with shape and type of input.
-    '''
+    """
     return Group(shape=shape, dtype=dtype, fill=1)
 
 def empty_like(other):
-    ''' 
+    """
     Create a new group with the same shape and type as another.
 
-    **Parameters**
-
-    other : array_like
+    :param array other:
         The shape and data-type of `other` defines the parameters of the
         returned group.
-
-    **Returns**
-
-    out : group
-        Unintialized group with same shape and type as `other`.
+    :return:
+        Uninitialized group with same shape and type as `other`.
 
     **Examples**
 
@@ -578,22 +593,18 @@ def empty_like(other):
     * :meth:`dana.empty` : Return a new uninitialized group.
     * :meth:`dana.ones_like` : Return a group of ones with shape and type of input.
     * :meth:`dana.zeros_like` : Return a group of zeros with shape and type of input.
-    '''
+    """
     return Group(shape=other.shape, dtype=other.dtype, fill=None)
 
 def zeros_like(other):
-    ''' 
+    """
     Create a new group of zeros with the same shape and type as another.
 
-    **Parameters**
 
-    other : array_like
+    :param array other:
         The shape and data-type of `other` defines the parameters of the
         returned group.
-
-    **Returns**
-
-    out : group
+    :return:
         Group of zeros with same shape and type as `other`.
 
     **Examples**
@@ -614,23 +625,18 @@ def zeros_like(other):
     * :meth:`dana.empty` : Return a new uninitialized group.
     * :meth:`dana.empty_like` : Return an uninitialized group shape and type of input.
     * :meth:`dana.ones_like` : Return a group of ones with shape and type of input.
-    '''
+    """
     return Group(shape=other.shape, dtype=other.dtype, fill=0)
 
 def ones_like(other):
-    '''
+    """
     Returns a group of ones with the same shape and type as a given array.
 
-    **Parameters**
-
-    other : group_like
-        The shape and data-type of other defines the parameters of the
+    :param array other:
+        The shape and data-type of `other` defines the parameters of the
         returned group.
-
-    **Returns**
-
-    out : group
-        Group of ones with same shape and type as other.
+    :return:
+        Group of ones with same shape and type as `other`.
 
     **Examples**
 
@@ -650,5 +656,5 @@ def ones_like(other):
     * :meth:`dana.empty` : Return a new uninitialized group.
     * :meth:`dana.empty_like` : Return an empty group with shape and type of input.
     * :meth:`dana.zeros_like` : Return a group of zeros with shape and type of input.
-    '''
+    """
     return Group(shape=other, dtype=other.dtype, fill=1)
